rekha.plots.HistogramPlot
=========================

.. currentmodule:: rekha.plots

.. autoclass:: HistogramPlot

   
   
   .. rubric:: Methods

   .. autosummary::
   
      ~HistogramPlot.add_annotation
      ~HistogramPlot.get_axes
      ~HistogramPlot.save
      ~HistogramPlot.save_all_formats
      ~HistogramPlot.show
      ~HistogramPlot.show_legend
      ~HistogramPlot.update_layout
   
   

   
   
   